%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% i3m.cls, v1.0, 2020/05/08
% Developed by Cal-Tek
% 
% This class file enables authors to prepare manuscripts for submission
%
% v1.0 Supported conferences:
% - i3m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
\ProvidesClass{i3m}[2020/05/08, v1.0]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\ExecuteOptions{num-refs}
\ProcessOptions\relax
\LoadClass[twoside,twocolumn]{article}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Packages

\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{ifpdf}
\RequirePackage{microtype}
\RequirePackage{euler}
\RequirePackage{merriweather}
\renewcommand{\ttdefault}{lmtt}
\RequirePackage[italic]{mathastext}
\RequirePackage{relsize}
\RequirePackage{ragged2e}
\RequirePackage{xcolor}
\RequirePackage{colortbl}
\RequirePackage{graphicx}
\RequirePackage{etoolbox,xpatch}
\RequirePackage{environ}
\RequirePackage{lastpage}
\RequirePackage{rotating}
\RequirePackage{lscape}
\RequirePackage{afterpage}
\RequirePackage[absolute]{textpos}
\RequirePackage{url}
\RequirePackage{newfloat}
\RequirePackage{mdframed}
\RequirePackage{titlesec}

\RequirePackage[colorlinks,allcolors=black,urlcolor=blue]{hyperref}

\RequirePackage[noblocks]{authblk}

\RequirePackage{scrextend}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% [Line-spacing]{Font size}
\changefontsizes[11.5pt]{9pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Page Margins

\RequirePackage{calc}
\RequirePackage{geometry}
\geometry{includefoot,
  hmargin=54pt, %left and right margins
  bottom=34pt, %bottom margin
  top=66pt, %top margin
  headsep=10pt,
  headheight=17.5pt,
  footnotesep=18pt,
  columnsep=18pt}
\setlength{\parindent}{12pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Definitions

%% Logos
\def\@licenselogo{Figures/byncndeu.pdf}

\def\@eventname{21\textsuperscript{st} International Multidisciplinary Modeling \& Simulation Multiconference}
\def\@eventacronym{I3M}
\def\@eventlogo{Figures/i3m-logo.pdf}

\def\@confname{Conference X}
\def\@confacronym{X}
\def\@confISSN{X}

\newcommand{\eventname}[1]{\def\@eventname{#1}}
\newcommand{\eventacronym}[1]{\def\@eventacronym{#1}}
\newcommand{\eventlogo}[1]{\def\@eventlogo{#1}}

\newcommand{\confname}[1]{\def\@confname{#1}}
\newcommand{\confacronym}[1]{\def\@confacronym{#1}}
\newcommand{\confISSN}[1]{\def\@confISSN{#1}}

%% Conference Logo
\colorlet{confcolour}{blue!40}
\definecolor{confcolour}{RGB}{128,0,0}%

%% Year and Starting Page
% \def\@confyear{2023}

\newcommand{\confyear}[1]{\def\@confyear{2024}}

%% Authors
\def\@runningauthor{}
\def\@runningtitle{}
\def\@corraddress{}
\def\@authnotes{}

\newcommand{\runningauthor}[1]{\def\@runningauthor{#1}}
\newcommand{\runningtitle}[1]{\def\@runningtitle{#1}}
\newcommand{\corraddress}[1]{\def\@corraddress{#1}}
\newcommand{\authnote}[1]{\appto{\@authnotes}{#1\par}}

%% Conference and symposium settings
\newcommand{\conference}[1]{%
  \ifstrequal{#1}{emss}{%
    \confname{36\textsuperscript{th} European Modeling \& Simulation Symposium}%
    \confacronym{EMSS}%
    \confISSN{2724-0029}%
  }{}
  \ifstrequal{#1}{hms}{%
    \confname{26\textsuperscript{th} International Conference on Harbour, Maritime \& Multimodal Logistics Modeling \& Simulation}%
    \confacronym{HMS}%
    \confISSN{2724-0339}%
  }{}
  \ifstrequal{#1}{mas}{%
    \confname{23\textsuperscript{rd} International Conference on Modeling \& Applied Simulation}%
    \confacronym{MAS}%
    \confISSN{2724-0037}%
  }{}
  \ifstrequal{#1}{imaaca}{%
    \confname{17\textsuperscript{th} International Conference on Integrated Modeling and Analysis in Applied Control and Automation}%
    \confacronym{IMAACA}%
    \confISSN{2724-0045}%
  }{}
  \ifstrequal{#1}{dhss}{%
    \confname{14\textsuperscript{th} International Defense and Homeland Security Simulation Workshop}%
    \confacronym{DHSS}%
    \confISSN{2724-0363}%
  }{}
  \ifstrequal{#1}{iwish}{%
    \confname{13\textsuperscript{th} International Workshop on Innovative Simulation for Healthcare}%
    \confacronym{IWISH}%
    \confISSN{2724-0371}%
  }{}
  \ifstrequal{#1}{sesde}{%
    \confname{12\textsuperscript{th} International Workshop on Simulation for Energy, Sustainable Development \& Environment}%
    \confacronym{SESDE}%
    \confISSN{2724-0061}%
  }{}
  \ifstrequal{#1}{foodops}{%
    \confname{10\textsuperscript{th} International Food Operations \& Processing Simulation Workshop}%
    \confacronym{FOODOPS}%
    \confISSN{2724-0355}%
  }
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Footnote
\RequirePackage[flushmargin,bottom,norule]{footmisc}
\appto{\footnotelayout}{\fontsize{6.5pt}{9.5pt}\selectfont}
\deffootnote{1.5em}{1.5em}{\thefootnotemark\enspace}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Page Header
\RequirePackage{fancyhdr}
\fancyhf{}
\renewcommand{\headrule}{\color{black!15}\rule{\textwidth}{2pt}}
\fancyhead[LE]{%
  \hspace*{12pt}%
  \fontsize{7.8pt}{10pt}\selectfont%
  \color{confcolour}%
  \textbf{\thepage}%
  \hspace{1em}\raisebox{-0.5pt}{|}\hspace{1em}%
  \textit{\@confname}, \@confacronym \hspace{0.5pt} \@confyear
}
\fancyhead[RO]{%
  \fontsize{7.8pt}{10pt}\selectfont%
  \color{confcolour}%
  \@runningauthor%
  \hspace{1em}\raisebox{-0.5pt}{|}\hspace{1em}%
  \textbf{\thepage}%
  \hspace*{12pt}%
}

\fancypagestyle{plain}{%
  \fancyhf{}
  \renewcommand{\headrule}{}
  \fancyfoot[R]{%
    \fontsize{7.8pt}{10pt}\selectfont%
    \color{confcolour}%
    \textbf{\thepage}\hspace*{12pt}%
  }
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Page Style
\pagestyle{fancy}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Info Box Top
\AtBeginDocument{%

  %%Savebox Copyright & DOI  
  \newsavebox{\confdetails}
  \newlength{\confdetailsheight}
  \savebox{\confdetails}{%
    \parbox{\textwidth-6pc+4pc+6.64pt}{%
    %% space before and after cell
    \vspace{\dimexpr 16pt-1em\relax}%
    %%font size and baselineskip
    \normalfont%
    \fontsize{8pt}{11pt}\selectfont%
    \@confISSN \hspace{1pt} $\copyright$ 2024 The Authors.\par
    \textcolor{confcolour}{doi: xx.xxxx/xxxx}\par
    %% space before and after cell
    \vspace{\dimexpr 8pt-1em\relax}%
  }}%
  \settototalheight{\confdetailsheight}{\usebox{\confdetails}}%
  %%Savebox Conference Details
  \newsavebox{\@gsheadbox}
  \newlength{\@gsheadboxheight}
  \savebox{\@gsheadbox}{%
    \parbox{\textwidth-6pc+4pc+6.64pt}{%
    \normalfont%
    \fontsize{8pt}{11pt}\selectfont%
    {\itshape\@confname} \par
    \@eventname \par
    %% space before and after cell
    \vspace{\dimexpr 16pt-2em\relax}%
    %%line
    {\color{black!15}\rule{\linewidth}{2pt}}\par%
    \usebox{\confdetails}
    }%
  }%
  \settototalheight{\@gsheadboxheight}{\usebox{\@gsheadbox}}%
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Authors Style
\RequirePackage{alphalph}
\newalphalph{\fnsymbolmult}[mult]{\@fnsymbol}{5}

\newcounter{authorfn}
\setcounter{authorfn}{1}
\newcommand{\authfn}[1]{%
  \fnsymbolmult{#1}%
}

\renewcommand\Authands{ and }
\renewcommand\AB@affilsepx{\par }
\renewcommand{\Authfont}{\fontsize{13pt}{18pt}\selectfont}
\renewcommand{\Affilfont}{\fontsize{9pt}{13pt}\selectfont}
\setlength{\affilsep}{21pt-9pt}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Front Page Header Style
\AtBeginDocument{
\renewcommand{\@maketitle}{%
  \textblockorigin{4pc+6.64pt}{4pc+6pt}
  
  %% Logos
  \begin{textblock*}{21pc}(0pt,0pt)

  \IfFileExists{\@eventlogo}{%
    \includegraphics[height=\@gsheadboxheight]{\@eventlogo}
  }{%
    \fbox{\begin{minipage}[b][\@gsheadboxheight]{\@gsheadboxheight}%
    \raggedright Placeholder for i3m logo \@eventlogo
    \end{minipage}}%
  }
  \end{textblock*}
  
  %% Box Conference Info
  \begin{textblock*}{\textwidth-21pc}(6pc,0pt)
  \usebox{\@gsheadbox}
  \end{textblock*}%
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Title & Author Style
  \null\vspace*{\dimexpr 11pc+11pt-5pc-6pt\relax}%
  \raggedright%
  \vspace{\dimexpr 26pt-18pt\relax}
  {\fontsize{18pt}{27pt}\bfseries\color{confcolour}\@title\par}
  \vspace{\dimexpr 26pt-13pt\relax}
  \@author\par
  \vspace{\dimexpr 15.5pt-1em}
  {%
    \renewcommand{\authfn}[1]{%
      \textsuperscript{\fnsymbolmult{##1}}%
    }
    {\fontsize{8pt}{11pt}\selectfont\@authnotes\par}%
  }
  \vspace{\dimexpr 16pt-3pt-1em\relax}
}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Abstract Style
\RequirePackage[style]{abstract}
\setlength{\absleftindent}{0pt}
\setlength{\absrightindent}{0pt}
\setlength{\absparindent}{12pt}
\setlength{\absparsep}{0pt}
\setlength{\abstitleskip}{16pt-8pt-\baselineskip}
\renewcommand{\abstractnamefont}{\fontsize{10pt}{12pt}\bfseries\color{confcolour}}
\renewcommand{\abstitlestyle}[1]{{\abstractnamefont #1}}
\renewcommand{\abstracttextfont}{\fontsize{8pt}{11pt}\selectfont}
\preto{\abstract}{%
  {\noindent\color{confcolour!40}\rule{\hsize+4pc+6.64pt}{3pt}}\par
  \vspace*{\dimexpr 23pt-10pt\relax}
}
\appto\abstract{\noindent\raggedright\ignorespaces}
\preto\endabstract{\par}

\newenvironment{keywords}
{\vspace*{\dimexpr 19pt-8pt-\baselineskip\relax}%
\noindent\fontsize{8pt}{11pt}\selectfont\textbf{Keywords}: \ignorespaces}%
{\par}

%%%%%%%%%%%%%%%%%%%%%%%%%
%% Text format

\NewEnviron{frontmatter}
{\twocolumn[%
   \BODY%
   \vspace*{\dimexpr 16pt-3pt-1em\relax}
   {\noindent\color{confcolour!40}\rule{\hsize+4pc+6.64pt}{3pt}}\par
    \vspace*{\dimexpr 23pt-1em\relax}]%
    
    %% License logo
    \begin{figure*}[b!]
    \fontsize{8pt}{11pt}\selectfont%
    \hrule%
    \vspace{\dimexpr 10pt-5pt\relax}%
    
    \IfFileExists{\@licenselogo}{%
	\includegraphics[height=25pt]{\@licenselogo}%
	}
	
   \end{figure*}
   
   %%License Footnote Details
   \newsavebox{\@licensebox}
   \newlength{\@licenseboxheight}
   \savebox{\@licensebox}{%
   \parbox{\textwidth-12pc+4pc+6.64pt}{%
   \normalfont%
   \fontsize{7.5pt}{11pt}\selectfont%
	\copyright \hspace{1pt} 2024 The Authors. %
	This article is an open access article 	distributed under the terms and conditions of the Creative Commons Attribution (CC BY-NC-ND) license (%
	\href{https://creativecommons.org/licenses/by-nc-nd/4.0/.}%
	{https://creativecommons.org/licenses/by-nc-nd/4.0/}). \par
   %% space before and after cell
   \vspace{\dimexpr 16pt-2em\relax}%
    }%
  }%
  \settototalheight{\@licenseboxheight}{\usebox{\@licensebox}}%
  
    %% Box Conference Info
    \begin{textblock*}{\textwidth-21pc}(10pc,710pt)
    \usebox{\@licensebox}
    \end{textblock*}%

}

%%%%%%%%%%%%%%%%%%%%%%%%%
%% Headings Format

\setcounter{secnumdepth}{3}
\titlelabel{\thetitle.\quad}
\titleformat*{\section}{\fontsize{10pt}{12pt}\bfseries\color{confcolour}}
\titlespacing*{\section}{0pt}{26.5pt-1em}{16pt-1em}
\titleformat*{\subsection}{\fontsize{9pt}{11pt}\bfseries\color{confcolour}}
\titlespacing*{\subsection}{0pt}{2pc-1em}{17pt-1em}
\titleformat*{\subsubsection}{\normalsize\bfseries\slshape\color{confcolour}}
\titlespacing*{\subsubsection}{0pt}{\baselineskip}{0pt}
\titleformat{\paragraph}[runin]{\normalsize\itshape}{\theparagraph}{0pt}{}[.\enspace]
\titlespacing*{\paragraph}{0pt}{\baselineskip}{0pt}
\titleformat{\subparagraph}[runin]{\relsize{-1}\uppercase}{\thesubparagraph}{0pt}{}[.\enspace]
\titlespacing*{\subparagraph}{0pt}{\baselineskip}{0pt}

%%%%%%%%%%%%%%%%%%%%%%%%%
%% Lists Format

\RequirePackage{enumitem}
\setlist{noitemsep}
\setlist[itemize]{leftmargin=12pt,topsep=16pt-1em}
\setlist[enumerate]{itemindent=14pt,topsep=16pt-1em,
 label={\arabic*.},labelsep=7pt,
 labelwidth=*,leftmargin=*,align=right}


%%%%%%%%%%%%%%%%%%%%%%%%%
%% Quotes and epigraphs

\RequirePackage{quoting}
\newcommand{\quotefont}{\fontsize{6.5pt}{9.5pt}\selectfont}
\quotingsetup{vskip=16pt-1em,indentfirst=false,font={quotefont},leftmargin=12pt,rightmargin=12pt}

\renewenvironment{quote}{\begin{quoting}}{\end{quoting}}

\renewenvironment{quotation}{\begin{quoting}}{\end{quoting}}

\newenvironment{epigraph}[1]
{\begin{quoting}[font={itshape,fontsize{7.5pt}{10.5pt}},vskip=15pt-1em,leftmargin=0pt,rightmargin=0pt]%
 \def\@quotesource{#1}}
{\par\vspace{\dimexpr 15pt-1em\relax}{\upshape---\@quotesource}\end{quoting}}

%%%%%%%%%%%%%%%%%%%%%%%%%
%% Space above/below equations

\g@addto@macro\normalsize{%
  \setlength\abovedisplayskip{\baselineskip}%
  \setlength\belowdisplayskip{\baselineskip}%
  \setlength\abovedisplayshortskip{\baselineskip}%
  \setlength\belowdisplayshortskip{\baselineskip}%
}

\RequirePackage{stfloats}
\RequirePackage{booktabs}
\RequirePackage{tabularx}

% Left-, right- and center-aligned auto-wrapping column types
\newcolumntype{L}{>{\raggedright\arraybackslash}X}
\newcolumntype{R}{>{\raggedleft\arraybackslash}X}
\newcolumntype{C}{>{\centering\arraybackslash}X}

%%%%%%%%%%%%%%%%%%%%%%%%%
%% Figures and tables

\AtBeginEnvironment{tabularx}{%
  \fontsize{7pt}{10pt}\selectfont
}
\AtBeginEnvironment{tabular}{%
  \fontsize{7pt}{10pt}\selectfont
}

\setlength{\aboverulesep}{11pt-1em}
\setlength{\belowrulesep}{11pt-1em}
\setlength{\heavyrulewidth}{0.5pt}
\setlength{\lightrulewidth}{0.5pt}
\arrayrulecolor{confcolour}

\newcommand{\tnote}[1]{\textsuperscript{\textit{#1}}}
\newlist{tablenotes}{itemize}{1}
\setlist[tablenotes]{label={},labelsep=0pt,leftmargin=0pt,topsep={\dimexpr 12pt-1em\relax}}
\appto{\tablenotes}{\fontsize{6pt}{9pt}\selectfont}

\RequirePackage[tableposition=top]{caption}
\DeclareCaptionFont{figcaptionfont}{\fontsize{7pt}{9pt}\selectfont}
\DeclareCaptionFont{tabcaptionfont}{\fontsize{7pt}{9pt}\selectfont}
\captionsetup{justification=justified,singlelinecheck=false,labelfont={bf},labelsep=period}
\captionsetup*[figure]{font=figcaptionfont,skip=10pt}
\captionsetup*[table]{font=tabcaptionfont,skip=10pt-1em}

%%%%%%%%%%%%%%%%%%%%%%%%%
%% Skips for floats

\setlength{\floatsep}{1pc+6pt}
\setlength{\intextsep}{1pc+6pt}
\setlength{\textfloatsep}{1pc+6pt}

%%%%%%%%%%%%%%%%%%%%%%%%%
%% References

\RequirePackage{natbib}
\bibliographystyle{apa}

\setlength{\bibhang}{11pt}
\setlength{\bibsep}{0pt}
\renewcommand{\bibnumfmt}[1]{#1.}
